pub struct CondaFingerprint {
pub conda_meta: CondaMetaFingerprint,
pub pack_meta: PackMetaFingerprint,
}Expand description
A fingerprint of a conda environment, used to detect if two envs are similar enough to facilitate mtime-based conda syncing.
Fields
conda_meta: CondaMetaFingerprintpack_meta: PackMetaFingerprintImplementations
Sourceimpl CondaFingerprint
impl CondaFingerprint
pub async fn from_env(path: &Path) -> Result<Self>
Sourcepub fn mtime_comparator(
a: &Self,
b: &Self,
) -> Result<Box<dyn Fn(&SystemTime, &SystemTime) -> Ordering + Send + Sync>>
pub fn mtime_comparator( a: &Self, b: &Self, ) -> Result<Box<dyn Fn(&SystemTime, &SystemTime) -> Ordering + Send + Sync>>
Create a comparator to compare the mtimes of files from two “equivalent” conda envs.
In particular, thie comparator will be aware of spuriuos mtime changes that occurs from
prefix replacement (via meta-pack), and will filter them out.